********************************************************************************
*******    SOMALIA HIGH-FREQUENCY COVID-19 SURVEY ROUND 2  		****************
****************************  ANALYSIS DO-FILE *********************************
********************************************************************************

*************************************
********** DO-FILE SET-UP ***********
*************************************

 * Root folder globals

global data_input ""   
global output ""  
   
// clear any pre-existing datasets from the memory
	clear all
// Load the data into Stata and set working directory
	use "$data_input\SHFPS_R2.dta", clear

	/* NOTES:
	Sample size is n=1756 households. This includes 1576 base respondents (also in wave 1), 20 non-base respondents not contacted through RDD, and 160 new (non-base) respondents contacted via RDD
	*/
// Record variable responses 98 and 99 as missing values
	ds, has(type numeric)	
		local numeric `r(varlist)'
	foreach var of local numeric {
		replace `var' = . if `var'== 98 | `var'== 99
	}
// Install tabout and mrtab packages from ssc to enable exporting of tables to excel
ssc install tabout, replace
ssc install mrtab, replace
*------------------------------------------------------------------------------*
*===============================================================================
* SECTION 2: HOUSEHOLD PROFILE	
*===============================================================================
*------------------------------------------------------------------------------*  

/* Respondent demographics/ Household profile (Not to include in brief report)
	Composition of households by:   Age/ Age-group, 
									Gender,
									Education level, 
									Status in HH, 
									Population type,
									State, 
									Household size
 */
 
 // 1. Age
    summarize age [aw= CSW]
	*Age group (generate grouping variable as per wave 1 data)
	tostring age, generate(age_group)
	replace age_group = "Less than 30" if age<30 
    replace age_group = "30-39" if age>=30 & age<40
    replace age_group = "40-49" if age>=40 & age<50
    replace age_group = "50-59" if age>=50 & age<60
    replace age_group = "Over 60" if age>=60
	
	/*Export to excel*/
	tabout age_group [aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append cell(col) format(2)
	tabout age_group state [aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append cell(col) format(2)
	tabout age_group pop_type [aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append cell(col) format(2)
	tabout age_group gender [aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append cell(col) format(2)
	tabout age_group state [aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append sum cell(mean age) format(2)
	tabout age_group pop_type [aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append sum cell(mean age) format(2)
	tabout age_group gender [aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append sum cell(mean age) format(2)
  
*------------------------------------------------------------------------------*  
  
 // 2. Gender
	*Export to excel
	tabout gender[aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append cell(col) format(2)
	tabout gender state [aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append cell(col) format(2)
	tabout gender pop_type [aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append cell(col) format(2)

*------------------------------------------------------------------------------*  
	
 // 3. Highest education level
	gen edu_gr1=0*(edu_level==0)+1*(edu_level>0 & edu_level<9)+2*(edu_level==9)+3*(edu_level>9 & edu_level<13)+4*(edu_level==13)+5*(edu_level>13 & edu_level<=17)+6*(edu_level==18)+7*(edu_level==97)
	replace edu_gr1 = . if mi(edu_level)
		label define edu_gr1 0 "Never attended school" 1"Attended primary" 2 "Completed primary" 3 "Attended secondary" 4 "Completed secondary"  5 "Post-secondary studies" 6 "Qurani School" 7 "Other"
		label values edu_gr1 edu_gr1
		
	gen edu_gr2=0*(edu_gr1>=0 & edu_gr1<2)+1*(edu_gr1==2 | edu_gr1==3)+2*(edu_gr1==4)+3*(edu_gr1==5)+4*(edu_gr1==6)+5*(edu_gr1==7)
	replace edu_gr2 = . if mi(edu_gr1)
		label define edu_gr2 0 "Never completed primary" 1 "Completed primary" 2 "Completed secondary" 3 "Attended tertiary" 4  "Completed Qurani School" 5 "Other"
		label values edu_gr2 edu_gr2

	* Export to excel
	tabout edu_gr2 pop_type  [aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append cell(col)  format(2)
	tabout edu_gr2 gender [aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append cell(col)  format(2)
    
*------------------------------------------------------------------------------*  	
	
// 4.Population type
	 tabout pop_type  [aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append cell(freq col) format(2)
		
*------------------------------------------------------------------------------*  	
		
// 5.Status of respondent within the household (head or other)
	tabout head  [aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append cell(col) format(2)
	tabout head gender  [aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append cell(col) format(2)
	
*------------------------------------------------------------------------------*  	
	
// 6.State
	tabout state [aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append cell(col) format(2)
	  
*------------------------------------------------------------------------------*  	  
	  
// 7.Household size
	summarize hhsize [aw=CSW]
	tabout hhsize pop_type [aw=CSW] using "$output\SHFS_R2_demo_Graphs.xls", append cell(col) format(2)
 

*------------------------------------------------------------------------------*
*===============================================================================
* SECTION 3: KNOWLEDGE & BEHAVIOR	
*===============================================================================
*------------------------------------------------------------------------------*  

*===============================================================================
* 1. Satisfaction with government measures
*===============================================================================

// Share of respondents aware of the measures taken by the government in response to COVID-19 (bar chart)
   	mrtab govt_measures_1 govt_measures_2 govt_measures_3 govt_measures_4 govt_measures_5 govt_measures_6 govt_measures_7 govt_measures_8 govt_measures_9 govt_measures_10 govt_measures_97 [aw=CSW], sort include descending
	* Not possible to directly export mrtable to excel --> copy-paste from log file

	/* Share of population aware of each government measure disaggregated by state and population type
	*foreach var of varlist govt_measures_1 govt_measures_4 govt_measures_2 govt_measures_3 govt_measures_10 {
			tabout state `var' [aw=CSW] using "$output\SHFS_R2_knowledge_Graphs.xls",cell( row)
		}
	*foreach var of varlist govt_measures_1 govt_measures_4 govt_measures_2 govt_measures_3 govt_measures_10 {
			tabout pop_type `var' [aw=CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell( row)
		}
	*/	

// Satisfaction
	 tabout govt_resp_sat [aw= CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls", append cell(freq col) format(2)
	 tabout govt_resp_sat state [aw= CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls", append cell(freq col) format(2)
	 tabout govt_resp_sat pop_type [aw= CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls", append cell(freq col) format(2)

 
*===============================================================================
* 2. Share of respondents adopting COVID-19 preventive behaviours
*=============================================================================== 
	 
	 replace b_wear_mask_often = . if b_wear_mask_often == 6
   	 replace b_wash_hands_often = . if b_wash_hands_often == 6
	 replace b_avoid_handshake = . if b_avoid_handshake == 96
	 replace b_avoid_groups = . if b_avoid_groups == 96
	 
	 gen wear_mask_atleasthalf = (b_wear_mask_often==1 | b_wear_mask_often==2 | b_wear_mask_often==3)
	 replace wear_mask_atleasthalf=. if mi(b_wear_mask_often)
	 label variable wear_mask_atleasthalf "Wears mask at least half of the time"
	 
	 * Export to excel
	 tabout b_wash_hands [aw= CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls",append cell(col) format(2)
	 tabout b_wash_hands_often [aw= CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls",append cell(col) format(2)
	 tabout b_avoid_handshake [aw= CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls",append cell(col) format(2)
	 tabout b_avoid_groups [aw= CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls",append cell(col) format(2)
	 tabout b_wear_mask_often [aw= CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls",append cell(col) format(2)
	 tabout wear_mask_atleasthalf [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls",append cell(col) format(2)
	 	
*===============================================================================
* 3. Mask wearing behaviour
*===============================================================================	
 
	 
// General mask-wearing behaviour
	 tabout b_wear_mask_often [aw= CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls",append cell(freq col) format(2)
*------------------------------------------------------------------------------*  	 
	 
// proportion of respondents who never wear masks by population type
	 * 43% of Somali population never wear masks
	 gen wear_mask_never = b_wear_mask_often==5
	 replace wear_mask_never = . if mi(b_wear_mask_often)
	 label variable wear_mask_never "Wears mask none of the time"
		 
	 tabout wear_mask_never [aw= CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls",append cell(col) format(2)
	 tabout wear_mask_never pop_type [aw= CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls",append cell(col) format(2)
	 tabout wear_mask_never state [aw= CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls",append cell(col) format(2)
	 
*------------------------------------------------------------------------------*  	 
	 
 // Proportion of population wearing masks more than half the time
	 tabout wear_mask_atleasthalf [aw= CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls",append cell(col) format(2)
	 tabout  wear_mask_atleasthalf pop_type [aw=CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls",append cell(col) format(2)
	 tabout  wear_mask_atleasthalf state [aw=CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls",append cell(col) format(2)

*------------------------------------------------------------------------------* 	 
	 
 // Reasons for not wearing masks more than half the time
	 tabout wear_mask_not [aw=CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls",append cell(freq col) format(2)	 
	 
*------------------------------------------------------------------------------* 	 
	 
 // Reasons for not wearing masks more than half the time
	 tabout mask_unable_access  [aw=CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls",append cell(freq col) format(2)
	 /* Group unable options into Financial reasons, Price increases, Supply reduction, Movement restrictions or limited transport
	 as follows:
			1	Shops do not sell masks (Supply reduction)
			2	Shops have run out of stock (Supply reduction)
			3	Local markets not operating/closed (Supply reduction)
			4	Limited/no transportation (Movement restrictions or limited transport)
			5	Restriction to go outside (Movement restrictions or limited transport)
			6	Increase in price (Price increases)
			7	No access to cash and cannot pay with credit card (Financial reasons)
			8	Cannot afford it (Financial reasons)
			9	Afraid to get out and get the virus (Movement restrictions or limited transport)
			97	Other (specify)
			98	Don't know
			99	Refuse to answer
	 */
	* Generate dummy categorical variables for mask_unable_accesswhy
	gen Fin_reasons= (mask_unable_access == 7 | mask_unable_access == 8)
	replace Fin_reasons = . if mi(mask_unable_access)
	gen Price_inc= mask_unable_access == 6
	replace Price_inc = . if mi(mask_unable_access)
	gen Supply_reduc= (mask_unable_access == 1 | mask_unable_access == 2 | mask_unable_access == 3)
	replace Supply_reduc = . if mi(mask_unable_access)
	gen Movement_restrict= (mask_unable_access == 4 | mask_unable_access == 5 | mask_unable_access == 9)
	replace Movement_restrict = . if mi(mask_unable_access)

	label variable Fin_reasons "No access to finances or cannot afford staple food"
	label variable Price_inc "Increase in price of staple food"
	label variable Supply_reduc "Local markets closure or no stock in shops"
	label variable Movement_restrict "Limited/no transportation, Restriction to go outside or afraid of virus"

	label define yn 0 "No" 1 "Yes"
	label values Fin_reasons yn
	label values Price_inc yn
	label values Supply_reduc yn
	label values Movement_restrict yn

	mrtab Fin_reasons Price_inc Supply_reduc Movement_restrict [aw=CSW],sort
								 

*===============================================================================
* 4. Vaccine acceptance	
*===============================================================================

// If an approved vaccine to prevent coronavirus was available right now at no cost, would you agree to be vaccinated?

// Distribution of respondents who would agree to be vaccinated disaggregated by gender, state, and population type
	tabout agree_vaccinated [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)
	tabout agree_vaccinated pop_type [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)
	tabout agree_vaccinated state [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)
	tabout agree_vaccinated gender [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)
	
*------------------------------------------------------------------------------*  
	
// Reasons for refusal to be vaccinated
	tabout not_vaccinated_reason [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)
	tabout notsure_vaccinated_reason [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)
	tabout notsure_vaccinated_reason pop_type [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)

*------------------------------------------------------------------------------*  	
	
// Willingness to pay for possible COVID-19 vaccine and reasons why
	tabout vaccine_will_pay [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)
	tabout vaccine_will_pay state [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)
	tabout vaccine_will_pay pop_type [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)

*------------------------------------------------------------------------------*  	
	
// Amount respondent is willing to pay out of pocket for vaccine
	summarize vaccine_pay_amt [aw=CSW] /* mean amount = SoS 86.24, min= 0, max = 2500*/ 
	*tabout vaccine_pay_amt [aw= CSW] using "$dropbox\Wave2_Tr_Graphs.xls", append cell(col)

*------------------------------------------------------------------------------*  	
	
// Willingness to get tested for COVID-19
	tabout will_test [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)
	tabout will_test pop_type [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)
	tabout will_test state [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)
	tabout will_test gender [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)

*===============================================================================
* 
*===============================================================================	

/* B) EVOLUTION OF KEY INDICATORS BETWEEN WAVE 1 AND WAVE 2

	NOTES: Use the sample that contains base respondents only;
*/

	// drop repondents not interviewsd in wave 1 
	keep if base_resp == 1 | base_resp == 2
	count
	*New sample size is n=1,596
 
*===============================================================================
* 5. Share of respondents concerned about risks linked to COVID-19 
*===============================================================================	 

	/* 	
	Preliminary Step : Generate dummy variabes for the various risk types: i) financial risk, ii) health risk
	iii) security risk, iv) political risk: limitation of rights, v) political risk: misuse of power and funds
	*/
	gen fin_risk_yn=(covid_threat==1 | covid_threat==2)
	replace fin_risk_yn = . if mi(covid_threat)
	gen health_risk_yn=(covid_feel==1 | covid_feel==2)
	replace health_risk_yn = . if mi(covid_feel)
	gen agree_sec_risk=(great_risk==4 | great_risk==5)
	replace agree_sec_risk = . if mi(great_risk)
	gen agree_limit_rights=(limit_rights==4 | limit_rights==5)
	replace agree_limit_rights = . if mi(limit_rights)
	gen agree_money_misuse=(money_misuse==4 | money_misuse==5)
	replace agree_money_misuse = . if mi(money_misuse)

	label variable fin_risk_yn "Considers COVID-19 a moderate or substantial threat to HH finances"
	label variable health_risk_yn "Worried about someone from my family getting sick from COVID-19"
	label variable agree_sec_risk "Agree that the COVID-19 puts me and my family at greater security risk"
	label variable agree_limit_rights "Agree that the response to COVID-19 will limit my rights and freedom"
	label variable agree_money_misuse "Concerned about misallocation of money and supplies for the COVID-19 response"

	label values agree_sec_risk yn
	label values agree_limit_rights yn
	label values agree_money_misuse yn
	label values fin_risk_yn yn
	label values health_risk_yn yn

   // Perform Risk analysis
   * Worried about someone in family getting seriously ill from COVID-19
	 tabout health_risk_yn [aw= CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)
   * Considers COVID-19 a moderate or substantial threat to household finances
	 tabout fin_risk_yn [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)
   * Agrees that response to COVID-19 will limit rights and freedom
	 tabout agree_limit_rights [aw= CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)
   * Concerned about misallocation of money and supplies for COVID-19 respons
	 tabout agree_money_misus [aw= CSW] using "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)
   * Agrees that COVID-19 poses personal security risk
	 tabout agree_sec_risk [aw= CSW] using  "$output\SHFS_R2_knowledge_Graphs.xls", append cell(col) format(2)
	 

*------------------------------------------------------------------------------*
*===============================================================================
* SECTION 4: EMPLOYMENT & INCOME
*===============================================================================
*------------------------------------------------------------------------------* 

*===============================================================================
* A) Employment Status
*===============================================================================	

	*codebook case
	replace case=. if case== 4
	tabout case [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(freq col) format(2)

// 1. Share of respondents working prior to and since COVID-19 outbreak (pie chart)
	
gen work_status = .
* Currently working or job to go back to 
replace work_status = 1 if work_now == 1
* Not currently working, but worked prior to COVID-19
replace work_status = 2 if work_now == 0 & case == 1
* Not currently working, and did not work prior to COVID-19	
replace work_status = 3 if work_now == 0 & case == 3
* Not currently working, but worked since COVID-19 outbreak
replace work_status = 4 if work_now == 0 & case == 2

label define work_status 1 "Currently working" 2 "No, but worked prior to COVID-19" 3 "No, and also did not work prior to COVID-19" 4 "No, but worked since COVID-19 outbreak"
label values work_status work_status

tabout work_status [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2)
	   
*------------------------------------------------------------------------------*	
	
// 2. Share of repondents involved in a family business that reported fewer or no sales since the outbreak of COVID-19
	gen buss_lessnorev = work_yn_13
	replace buss_lessnorev = 1 if (work_yn_13== 3 | work_yn_13== 4)
	replace buss_lessnorev = 0 if (work_yn_13== 1 | work_yn_13== 2)
	order work_yn_13  buss_lessnorev 
	tabout buss_lessnorev [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2)
		
	*Why were there no revenue from sales?		
	tabout work_yn_14 [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2)
	
	*Why was the revenue from the business sales less compared to the situation before March 20 2020?
	tabout work_yn_14b [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2)
	
	* Reason for no or less revenue from business sales compared to before March 20, 2020
	gen reas_lessnorev = work_yn_14
	replace reas_lessnorev = work_yn_14b if mi(work_yn_14) & !mi(work_yn_14b)
	tabout reas_lessnorev [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2)   
		  
*------------------------------------------------------------------------------*		  
		   
// 3. Main reasons for stopping work activity between.... (horiz bar chart)
   	
	// Resasons for stopping work for those working in the baseline and prior to COVID-19
	tabout nowork_why [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2)   
	
*===============================================================================
* B) Remittances
*===============================================================================		
	
////  /*Amount, frequency and cost all reduced since July for the majority of the Somali population.

//1. Change in remittances frequency and amount received   
	tab remittance_freq pop_type [aw=CSW], col /*Since July has the frequency of remittances changed?*/ 
	tab remittance_amt pop_type [aw=CSW],col	/*Since July has the amount of remittances changed? */
	tab remittance_cost	pop_type [aw=CSW],col /*Since July has there been any change in the cost of the remittance services you use?*/

	tabout remittance [aw=CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2)  
	tabout remittance_freq [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2)  
	tabout remittance_freq pop_type [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2)  
	tabout remittance_amt [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2)  
	tabout remittance_amt pop_type [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2)  
	tabout remittance_cost [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2)  
	tabout remittance_cost pop_type [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2)  
	
*===============================================================================
* C) Income
*===============================================================================	
	
// 1. Share of respondents experiencing a change in income by income sources and overall. (stacked horiz bar chart)
	replace income_farming =. if  income_farming == 4 
	replace income_business =. if  income_business == 4
	replace income_wage =. if  income_wage == 4
	replace income_benefits =. if  income_benefits == 4
	replace income_assistance_fam =. if  income_assistance_fam == 4
	replace income_assistance_oth =. if  income_assistance_oth== 4
	replace income_assets =. if  income_assets == 4
	replace income_pension =. if  income_pension == 4
	replace income_gov =. if  income_gov == 4
	replace income_ngo =. if  income_ngo == 4
	
	/* Export to excel*/
	tabout income_farming [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2) 
	tabout income_business [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2) 
	tabout income_wage [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2) 
	tabout income_benefits [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2) 
	tabout income_assistance_fam [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2) 
	tabout income_assistance_oth [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2) 
	tabout income_assets [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2) 
	tabout income_pension [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2) 
	tabout income_gov [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2) 
	tabout income_ngo [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2) 

// Reduction in any income source	
gen anyincome = 0
replace anyincome = 1 if !mi(income_farming) | !mi(income_business) | !mi(income_wage) | !mi(income_benefits) | !mi(income_assistance_fam) ///
 | !mi(income_assistance_oth) | !mi(income_assets) | !mi(income_pension) | !mi(income_gov) | !mi(income_ngo) | !mi(income_other)

gen totincome_red = 0 if anyincome == 1
replace totincome_red = 1 if income_farming == 3 | income_business == 3 |	income_wage == 3 | income_benefits == 3 | income_assistance_fam == 3 | income_assistance_oth == 3 | income_assets == 3 | income_pension == 3 | income_gov == 3 | income_ngo == 3 
tabout totincome_red [aw= CSW] using "$output\SHFS_R2_employment_Graphs.xls", append cell(col) format(2) 	
	
*------------------------------------------------------------------------------*
*===============================================================================
* SECTION 5: ACCESS
*===============================================================================
*------------------------------------------------------------------------------*  

*===============================================================================
* A) Food staples
*===============================================================================

//1. Access to most preferred staple foods (namely, Rice, Beans, and Maize)
	tab staple_food [aw= CSW], sort /*Rice(option 4)=59%, Maize(option 2)=19%, Beans(Option 1)=12%*/
 
	*Export to Excel and draw 3 pie charts
	* Beans
	tabout staple_able [aw= CSW] if staple_food==1 using  "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 
	* Maize
	tabout staple_able [aw= CSW] if staple_food==2 using  "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 
	* Rice
	tabout staple_able [aw= CSW] if staple_food==4 using  "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 
	 
*------------------------------------------------------------------------------*	
	
//2. Reasons for lack of access to preferred staple foods
	tab staple_unable_why [aw= CSW],sort
	/* Group unable options into Financial reasons, Price increases, Supply reduction, Movement restrictions or limited transport
	as follows (as in brief report):
			1	Shops have run out of stock (Supply reduction)
			2	Local markets not operating / closed (Supply reduction)
			3	Limited / no transportation (Movement restrictions or limited transport)
			4	Restriction to go outside (Movement restrictions or limited transport)
			5	Increase in price (Price increases)
			6	No access to cash and cannot pay with credit card (Financial reasons)
			7	Cannot afford it (Financial reasons)
			8	Afraid to get out and get the virus (Movement restrictions or limited transport)
			97	Other
			98	Dont know
			99	Refuse to answer
*/
// Generate new variables and value labels from staple_unable_why to match those in the brief report
	gen Financial_reasons= (staple_unable_why == 6 | staple_unable_why == 7)
	replace Financial_reasons = . if mi(staple_unable_why)
	gen Price_increases= staple_unable_why == 5
	replace Price_increases = . if mi(staple_unable_why)
	gen Supply_reduction= (staple_unable_why == 1 | staple_unable_why == 2)
	replace Supply_reduction = . if mi(staple_unable_why)
	gen Move_restrict= (staple_unable_why == 3 | staple_unable_why == 4 | staple_unable_why == 8)
	replace Move_restrict = . if mi(staple_unable_why)

	label variable Financial_reasons "No access to finances or cannot afford staple food"
	label variable Price_increases "Increase in price of staple food"
	label variable Supply_reduction "Local markets closure or no stock in shops"
	label variable Move_restrict "Limited/no transportation, restriction to go outside, or afraid of virus"

	*label define yn 0 "No" 1 "Yes"
	label values Financial_reasons yn
	label values Price_increases yn
	label values Supply_reduction yn
	label values Move_restrict yn
	
	tabout Financial_reasons [aw= CSW] using  "$output\SHFS_R2_access_Graphs.xls", append cell(col) format(2) 
	tabout Price_increases [aw= CSW] using  "$output\SHFS_R2_access_Graphs.xls", append cell(col) format(2) 
	tabout Supply_reduction [aw= CSW] using  "$output\SHFS_R2_access_Graphs.xls", append cell(col) format(2) 
	tabout Move_restrict [aw= CSW] using  "$output\SHFS_R2_access_Graphs.xls", append cell(col) format(2) 
	tabout staple_unable_why [aw= CSW] using  "$output\SHFS_R2_access_Graphs.xls", append cell(col) format(2) 
	
	mrtab Financial_reasons Price_increases Supply_reduction Move_restrict [aw=CSW],sort

*------------------------------------------------------------------------------*
	
// During the last 30 days, was there a time when: you, or any other adult in your household;
	* a) went without eating for a whole day because of a lack of money or other resources?	
	tab fies_no_eat [aw=CSW]
	* b) were hungry but did not eat because there was not enough money or other resources for food?
	tabulate fies_hungry [aw=CSW]
	* c) ran out of food because of a lack of money or other resources?
	tab fies_no_food [aw=CSW]
	* Export to excel and draw 3 pie charts (or comparative bar charts with wave 1 data)
	tabout fies_no_eat [aw= CSW] using "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 
	tabout fies_hungry [aw= CSW] using "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 
	tabout fies_no_food [aw= CSW] using "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 

	
*===============================================================================
* B) Medicine
*===============================================================================	
	
// Share of households unable to buy medicines (pie chart)and reasons why (bar chart)
	*In the last week, has your household been unable to buy Medicine?
	* Export to excel and draw 1 pie chart bar chart
	tabout medicine_unable [aw= CSW] using  "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 
	tabout medicine_unable_why [aw= CSW] using  "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 

*===============================================================================
* C) Medical services
*===============================================================================		
	
// Share of households needing medical care, unable to access medical care, and reasons cited (3 bar charts) 
	tabout need_medical [aw= CSW] using  "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 
	tabout need_medical_able [aw= CSW] using  "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 
	tabout need_medical_notable_why [aw= CSW] using  "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 

*===============================================================================
* D) Schooling
*===============================================================================	
	
// Were any of the children (7-17 years) attending school before schools were closed due to coronavirus?
	tabout attend_school [aw= CSW] using  "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 
	
	** For those who previously attended school
	*In the last week, have these children been engaged in any education or learning activities?
	tabout edu_last_week [aw= CSW] using  "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 
	
	*In what types of education or learning activities have the children been engaged in the last week? 
	tabout edu_type [aw= CSW] using  "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 

*===============================================================================
* E) Drinking water
*===============================================================================	
		
// In the last week, did your household have access to sufficient drinking water to meet household needs?
	rename no_drink_water access_drinking_water

	tabout access_drinking_water [aw= CSW] using   "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 
	
*===============================================================================
* F) Water & soap for handwashing
*===============================================================================		
	
// Availability of water and soap for handwash
	*In the last week did you have sufficient soap/water to wash your hands when needed?
	tabout no_water [aw= CSW] using   "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 
	tabout no_soap [aw= CSW] using   "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 

*===============================================================================
* G) Financial services
*===============================================================================		
	
// Financial services	
	* In the last week, did you need to access financial services?	
	tabout fin_need [aw= CSW] using  "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 
	* Were you able to successfully access it?
	tabout fin_access [aw= CSW] using  "$output\SHFS_R2_access_Graphs.xls", append cell(freq col) format(2) 
	
*===============================================================================
* SUMMARY
*===============================================================================		
	
	mrtab edu_last_week access_drinking_water no_water no_soap fin_access [aw=CSW],sort include descending
	/* NOTE: Copy-paste table from log file; 
			 Table values show the "NO" responses- use as they are except for edu_last_week as in the brief report*/

*------------------------------------------------------------------------------*
*===============================================================================
* SECTION 6: SHOCKS & COPING
*===============================================================================
*------------------------------------------------------------------------------*  

/* Group shocks into 5 categories namely; economic, food security, health, security, and natural disasters as follows:
		A. Economic shocks: loss of a wage job, closure of family business, disruption of farming activities,input price increase or unavailability,output reduction or output price decrease  
		B. Food security shocks: Increase in food prices
		C. Security: theft and conflicts
		D. Health shocks: Illness
		E. Natural disasters: Droughts, flooding, locust invasion
	Cluster the coping mechanisms for all groups of shocks
 */
*********************************************************************************************************************
// Preliminary Step 1: Cluster all input and output shocks

	egen input_shock = rowmax(input_price_up input_unavailable)
	egen output_shock = rowmax(output_price_down output_reduction)
	
	label var input_shock "Inputs not available or increase price of inputs"
	label var output_shock "Reduction of output amount or output price"

	forvalues i=1/16 {
	g cope_input_`i'=(cope_input_price_up_`i'==1 | cope_input_unavailable_`i'==1)
	replace cope_input_`i'=. if input_shock==0
	replace cope_input_`i'=. if mi(input_shock)
	}
	forvalues i=1/16 {
	g cope_output_`i'=(cope_output_price_down_`i'==1 | cope_output_reduction_`i'==1)
	replace cope_output_`i'=. if output_shock==0
	replace cope_output_`i'=. if mi(output_shock)
	}

// Preliminary Step 2: Final clustering of all shocks into 5 groups
	
	**Economic shocks
	* job_loss business_close farm_disruption input_shock  output_shock
	egen economic_shock = rowmax(job_loss business_close farm_disruption input_price_up input_unavailable output_price_down output_reduction)
	tabout economic_shock [aw= CSW] using  "$output\SHFS_R2_shocks_Graphs.xls", append cell(col) format(2) 

	**Security shock
	* theft conflict 
	egen security_shock= rowmax(theft conflict)
	tabout security_shock [aw= CSW] using  "$output\SHFS_R2_shocks_Graphs.xls", append cell(col) format(2) 

	**Natural disasters shock
	* locust flooding drought
	egen disaster_shock= rowmax(locust flooding drought)
	tabout disaster_shock [aw= CSW] using  "$output\SHFS_R2_shocks_Graphs.xls", append cell(col) format(2) 

	**Food security shock
	* food_price_up
	gen foodsec_shock = food_price_up == 1
	replace foodsec_shock = . if mi(food_price_up)
	tabout foodsec_shock [aw= CSW] using  "$output\SHFS_R2_shocks_Graphs.xls", append cell(col) format(2) 
	
	forvalues i=1/16 {
	rename cope_food_price_up_`i' cope_foodsec_`i'
	}

	**Health shock
	* illness 
	gen health_shock = illness == 1
	replace health_shock = . if mi(illness)
	tabout health_shock [aw= CSW] using  "$output\SHFS_R2_shocks_Graphs.xls", append cell(col) format(2) 
	
	forvalues i=1/16 {
	rename cope_illness_`i' cope_health_`i'
	}

*===============================================================================
* 1. Share of households affected by various shocks since July 2020
*===============================================================================	
		
*a) unclustered shocks
	mrtab job_loss business_close farm_disruption input_price_up input_unavailable output_price_down output_reduction food_price_up conflict theft illness flooding drought locust [aw=CSW],include 
	/* NOTE: Copy -paste table form log file 
				 Table values show proportion of population Not affected by shocks */
		
*b)clustered shocks
	mrtab economic_shock foodsec_shock security_shock disaster_shock health_shock [aw=CSW], include sort descending
	/* NOTE: Copy-paste table from log file and plot a horizintal bar chart as in brief report;
				 Table values show proportions affected by shocks */

*********************************************************************************************************				 			 
*********************************************************************************************************				 
**********************************************************************************************************
/* The 16 coping options were:
	1	Sale of assets (agricultural and non-agricultural assets)
	2	Engaged in additional income generating activities
	3	Received assistance from friends & family
	4	Borrowed from friends & family
	5	Took a loan from a financial institution
	6	Credited purchases
	7	Delayed payment obligations
	8	Sold harvest in advance
	9	Reduced food consumption
	10	Reduced non-food consumption
	11	Relied on savings
	12	Received assistance from ngo
	13	Took advanced payment from employer
	14	Received assistance from government
	15	Was covered by insurance policy
	16	Did nothing
	97	Other (specify)
	98	Dont know
	99	Refuse to answer
*/

// Preliminary Step 3: Clustering coping mechanism in light of the newly-created marco shock categories (economic, security, natural disasters)
	forvalues i=1/16 {
	gen cope_economic_`i'=(cope_job_loss_`i'==1 | cope_business_close_`i'==1 | cope_farm_disruption_`i' ==1| cope_input_`i'==1| cope_output_`i'==1)
	replace cope_economic_`i'=. if economic_shock==0 | economic_shock==.
	}

	forvalues i=1/16 {
	g cope_security_`i'=(cope_theft_`i'==1 | cope_conflict_`i'==1)
	replace cope_security_`i'=. if security_shock==0 | security_shock==.
	}

	forvalues i=1/16 {
	g cope_disaster_`i'=(cope_locust_`i'==1 | cope_flooding_`i'==1 | cope_drought_`i'==1)
	replace cope_disaster_`i'=. if disaster_shock==0 | disaster_shock==.
	}

// Preliminary Step 4: Clustering of options for coping mechanisms

	*Assistance from family/friends & Borrowing from family/friends
	foreach x in economic security disaster foodsec health {
	gen cope_`x'_familyassist=(cope_`x'_3==1)
	replace cope_`x'_familyassist=. if `x'_shock==0 | `x'_shock==.
	}
	*Borrowing from family/friends
	foreach x in economic security disaster foodsec health {
	gen cope_`x'_loanfamily=(cope_`x'_4==1)
	replace cope_`x'_loanfamily=. if `x'_shock==0 | `x'_shock==.
	}

	*Financial moves (i.e. delaying payment, requiring advance salary, etc.)
	foreach x in economic security disaster foodsec health {
	g cope_`x'_fin=(cope_`x'_6==1 | cope_`x'_7==1 | cope_`x'_13==1)
	replace cope_`x'_fin=. if `x'_shock==0 | `x'_shock==.
	}

	*Assistance from NGO and Govt.
	foreach x in economic security disaster foodsec health {
	g cope_`x'_humass=(cope_`x'_12==1 | cope_`x'_14==1)
	replace cope_`x'_humass=. if `x'_shock==0 | `x'_shock==.
	}
	*Reduced food and non-food consumption
	foreach x in economic security disaster foodsec health {
	g cope_`x'_cons=(cope_`x'_10==1 | cope_`x'_9==1)
	replace cope_`x'_cons=. if `x'_shock==0 | `x'_shock==.
	}
	
	**Renaming other vars
	foreach x in economic security disaster foodsec health {
	rename cope_`x'_1 cope_`x'_sale
	rename cope_`x'_5  cope_`x'_instloan
	rename cope_`x'_8  cope_`x'_harvest
	rename cope_`x'_11  cope_`x'_savings
	rename cope_`x'_15  cope_`x'_insurance
	rename cope_`x'_16  cope_`x'_nothing
	rename cope_`x'_2  cope_`x'_otheract
	}
	
	** Renaming of vars
	foreach x in economic security disaster foodsec health {
	label var cope_`x'_sale "Sale of assets (agricultural and non-agricultural assets)"
	label var cope_`x'_otheract "Engaged in additional income generating activities"
	label var cope_`x'_familyassist "Family assistance"
	label var cope_`x'_loanfamily "Took a loan from family or friends"
	label var cope_`x'_instloan "Took a loan from a financial institution"
	label var cope_`x'_fin "Financial solutions (i.e. purchase on credit, delayed obligation payments, took advance salary)"
	label var cope_`x'_harvest "Sold harvest in advance"
	label var cope_`x'_cons "Reduced food/non-food consumption"
	label var cope_`x'_savings "Relied on savings"
	label var cope_`x'_humass "Received humanitarian assistance from Gov/NGO"
	label var cope_`x'_insurance "Was covered by insurance policy"
	label var cope_`x'_nothing "Did nothing"
	}
	
foreach x in sale otheract familyassist loanfamily instloan fin harvest cons savings humass insurance nothing	{
	egen cope_`x' = rowmax(cope_economic_`x' cope_security_`x' cope_disaster_`x' cope_foodsec_`x' cope_health_`x')
	
		tabout cope_`x' [aw= CSW] using  "$output\SHFS_R2_shocks_Graphs.xls", append cell(freq col) format(2) 
}


*===============================================================================
* 2. Mechanisms of coping with Household shocks (clustered)
*===============================================================================	

*A) Economic shocks
	mrtab cope_economic_sale cope_economic_otheract  cope_economic_familyassist cope_economic_loanfamily cope_economic_instloan cope_economic_fin cope_economic_harvest cope_economic_cons cope_economic_savings  cope_economic_humass cope_economic_insurance cope_economic_nothing [aw=CSW], include
*B) Food Security shocks
	mrtab cope_foodsec_sale cope_foodsec_otheract  cope_foodsec_familyassist cope_foodsec_loanfamily cope_foodsec_instloan cope_foodsec_fin cope_foodsec_harvest cope_foodsec_cons cope_foodsec_savings  cope_foodsec_humass cope_foodsec_insurance cope_foodsec_nothing [aw=CSW], include 
*C) Health shocks
	mrtab cope_health_sale cope_health_otheract  cope_health_familyassist cope_health_loanfamily  cope_health_instloan cope_health_fin cope_health_harvest cope_health_cons cope_health_savings  cope_health_humass cope_health_insurance cope_health_nothing [aw=CSW], include
*D) Natural disasaters shocks
	mrtab cope_disaster_sale cope_disaster_otheract  cope_disaster_familyassist cope_disaster_loanfamily cope_disaster_instloan cope_disaster_fin cope_disaster_harvest cope_disaster_cons cope_disaster_savings  cope_disaster_humass cope_disaster_insurance cope_disaster_nothing[aw=CSW], include
*E) Security shocks 
	mrtab cope_security_sale cope_security_otheract  cope_security_familyassist cope_security_loanfamily cope_security_instloan cope_security_fin cope_security_harvest cope_security_cons cope_security_savings  cope_security_humass cope_security_insurance cope_security_nothing[aw=CSW], include

/*NOTE: Copy-paste all 5 tables from the log file into excel;
		Combine coping mechanisms across all shocks - in order of mentioning- then sort in descending order and draw a horizontal bar chart as in brief report
*/
**************************************************************************************************
